@@ -12,7 +12,7 @@ use vars (qw/@ISA @EXPORT_OK/);
 
 @EXPORT_OK = qw(stream_file);
 
-our $VERSION = '2.06';
+our $VERSION = '2.10';
 
 sub stream_file {
     my ( $self, $file_or_fh, $bytes ) = @_;
@@ -46,7 +46,7 @@ sub stream_file {
 
     # Check for a existing type header set with or without a hypheout a hyphen
     unless ( $existing_headers{'-type'} ||  $existing_headers{'type'} ) {
-    	my $mime_type;
+        my $mime_type;
 
         eval {
             require File::MMagic;
@@ -75,20 +75,26 @@ sub stream_file {
         $self->header_add('-attachment' => $basename);
     }
 
-    $self->header_type( 'none' );
-    print $self->query->header( $self->header_props() );
-
-    # This reads in the file in $byte size chunks
-    my $first;
-    # File::MMagic may have read some of the file, so seek back to the beginning
-    seek($fh,0,0);
-    while ( read( $fh, my $buffer, $bytes ) ) {
-		print $buffer;
+    unless ( $ENV{'CGI_APP_RETURN_ONLY'} ) {
+        $self->header_type( 'none' );
+        print $self->query->header( $self->header_props() );
     }
 
-    print '';	# print a null string at the end
+    # This reads in the file in $byte size chunks
+    # File::MMagic may have read some of the file, so seek back to the beginning
+    my $output = "";
+    seek($fh,0,0);
+    while ( read( $fh, my $buffer, $bytes ) ) {
+        if ( $ENV{'CGI_APP_RETURN_ONLY'} ) {
+            $output .= $buffer;
+        } else {
+            print $buffer;
+        }
+    }
+
+    print '' unless $ENV{'CGI_APP_RETURN_ONLY'}; # print a null string at the end
     close ( $fh );
-    return 1;
+    return $ENV{'CGI_APP_RETURN_ONLY'} ? \$output : 1;
 }
 
 1;
